slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSCISSGetUseST

Gets the flag for using the ST object in the CISS solver.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSCISSGetUseST(EPS eps,PetscBool *usest)

Not Collective

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameters

| usest | - boolean flag indicating if the ST object is being used

### See Also

EPSCISSSetUseST()

### Level

advanced

### Location

src/eps/impls/ciss/ciss.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages